#ifndef CHROMEOS_PLATFORMS_CAMERA_LIBHDR_AE_STATS_INTEL_IPU6_H_
#define CHROMEOS_PLATFORMS_CAMERA_LIBHDR_AE_STATS_INTEL_IPU6_H_

#include <cstdint>
#include <vector>

// The AE stats defined in this file is duplicated to:
//
// googlex/gcam/ae/ae_stats_intel_ipu6.h.

// LINT.IfChange

namespace cros {

// Intel IPU6 AE stats block data.
struct AeStatsGridBlockIntelIpu6 {
  // `avg_gr`, `avg_r`, `avg_b`, `avg_gb` are average pixel values of the R, Gr,
  // Gb, B pixels in the block scaled down to [0, 255].
  uint8_t avg_gr;
  uint8_t avg_r;
  uint8_t avg_b;
  uint8_t avg_gb;

  // `sat` is the proportion of saturated pixels in the block scaled to
  // [0, 255].
  uint8_t sat;
};

// Intel IPU6 AE stats.
struct AeStatsIntelIpu6 {
  // `white_level` is the white level used by the ISP as saturation threshold.
  int white_level;

  // `grid_width` and `grid_height` specify the dimension of the AE stats grid.
  int grid_width, grid_height;

  // `grid_width` * `grid_height` blocks of AE stats data in row-major order.
  std::vector<AeStatsGridBlockIntelIpu6> grid_blocks;
};

}  // namespace cros

// LINT.ThenChange(//depot/google3/googlex/gcam/ae/ae_stats_intel_ipu6.h)

#endif  // CHROMEOS_PLATFORMS_CAMERA_LIBHDR_AE_STATS_INTEL_IPU6_H_
